KernelBuilder

Struct KernelBuilder 

pub struct KernelBuilder { /* private fields */ }
Builder for kernel configuration.

Example

VmBuilder::new()
    .kernel(|k| {
        k.krunfw_path("/path/to/libkrunfw.dylib")
            .cmdline("debug")
    });

Implementations

Source

impl KernelBuilder

pub fn new() -> Self

Create a new kernel builder.

pub fn cmdline(self, cmdline: &str) -> Self

Append to the kernel command line.

pub fn krunfw_path(self, path: impl AsRef<Path>) -> Self

Set an explicit path to the libkrunfw shared library.

When not set, the OS dynamic linker’s default search path is used.

pub fn init_path(self, path: impl AsRef<Path>) -> Self

Set the path to the init binary inside the guest.

This controls the kernel init= parameter. When not set, defaults to /init.krun.